@@ -39,7 +39,7 @@ class TDEAboutData;
 
 class MALConduitFactory : public KLibFactory
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
@@ -51,7 +51,7 @@ public:
 protected:
 	virtual TQObject* createObject( TQObject* parent = 0,
 		const char* name = 0,
-		const char* classname = TQOBJECT_OBJECT_NAME_STRING,
+		const char* classname = "TQObject",
 		const TQStringList &args = TQStringList() );
 private:
 	TDEInstance *fInstance;
