@@ -74,7 +74,7 @@ public:
 
 class VCalConduitBase : public ConduitAction
 {
-        Q_OBJECT
+        TQ_OBJECT
   
 public:
 	VCalConduitBase(KPilotLink *,
