@@ -42,7 +42,7 @@ class TDEListView;
 
 class GenericDBWidget : public PilotComponent
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
