@@ -231,8 +231,8 @@ void KPilotInstaller::setupWidget()
 	fManagingWidget->setMinimumSize(fManagingWidget->sizeHint());
 	fManagingWidget->show();
 	setCentralWidget(fManagingWidget);
-	connect( fManagingWidget, TQT_SIGNAL( aboutToShowPage ( TQWidget* ) ),
-			TQT_TQOBJECT(this), TQT_SLOT( slotAboutToShowComponent( TQWidget* ) ) );
+	connect( fManagingWidget, TQ_SIGNAL( aboutToShowPage ( TQWidget* ) ),
+			this, TQ_SLOT( slotAboutToShowComponent( TQWidget* ) ) );
 
 	initIcons();
 	initMenu();
@@ -286,7 +286,7 @@ void KPilotInstaller::initComponents()
 
 #undef ADDICONPAGE
 
-	TQTimer::singleShot(500,this,TQT_SLOT(initializeComponents()));
+	TQTimer::singleShot(500,this,TQ_SLOT(initializeComponents()));
 }
 
 
@@ -518,12 +518,12 @@ void KPilotInstaller::initMenu()
 	syncPopup->setWhatsThis(i18n("Select the kind of HotSync to perform next. "
 		"This applies only to the next HotSync; to change the default, use "
 		"the configuration dialog."));
-	connect(syncPopup, TQT_SIGNAL(activated()),
-		TQT_TQOBJECT(this), TQT_SLOT(slotHotSyncRequested()));
+	connect(syncPopup, TQ_SIGNAL(activated()),
+		this, TQ_SLOT(slotHotSyncRequested()));
 
 	// File actions, keep this list synced with kpilotui.rc and pilotDaemon.cpp
 	a = new TDEAction(i18n("&HotSync"), CSL1("hotsync"), 0,
-		TQT_TQOBJECT(this), TQT_SLOT(slotHotSyncRequested()),
+		this, TQ_SLOT(slotHotSyncRequested()),
 		actionCollection(), "file_hotsync");
 	a->setToolTip(i18n("Next HotSync will be normal HotSync."));
 	a->setWhatsThis(i18n("Tell the daemon that the next HotSync "
@@ -531,7 +531,7 @@ void KPilotInstaller::initMenu()
 	syncPopup->insert(a);
 
 	a = new TDEAction(i18n("Full&Sync"), CSL1("fullsync"), 0,
-		TQT_TQOBJECT(this), TQT_SLOT(slotFullSyncRequested()),
+		this, TQ_SLOT(slotFullSyncRequested()),
 		actionCollection(), "file_fullsync");
 	a->setToolTip(i18n("Next HotSync will be a FullSync."));
 	a->setWhatsThis(i18n("Tell the daemon that the next HotSync "
@@ -539,7 +539,7 @@ void KPilotInstaller::initMenu()
 	syncPopup->insert(a);
 
 	a = new TDEAction(i18n("&Backup"), CSL1("backup"), 0,
-		TQT_TQOBJECT(this), TQT_SLOT(slotBackupRequested()),
+		this, TQ_SLOT(slotBackupRequested()),
 		actionCollection(), "file_backup");
 	a->setToolTip(i18n("Next HotSync will be backup."));
 	a->setWhatsThis(i18n("Tell the daemon that the next HotSync "
@@ -547,7 +547,7 @@ void KPilotInstaller::initMenu()
 	syncPopup->insert(a);
 
 	a = new TDEAction(i18n("&Restore"), CSL1("restore"), 0,
-		TQT_TQOBJECT(this), TQT_SLOT(slotRestoreRequested()),
+		this, TQ_SLOT(slotRestoreRequested()),
 		actionCollection(), "file_restore");
 	a->setToolTip(i18n("Next HotSync will be restore."));
 	a->setWhatsThis(i18n("Tell the daemon that the next HotSync "
@@ -555,7 +555,7 @@ void KPilotInstaller::initMenu()
 	syncPopup->insert(a);
 
 	a = new TDEAction(i18n("Copy Handheld to PC"), TQString(), 0,
-		TQT_TQOBJECT(this), TQT_SLOT(slotHHtoPCRequested()),
+		this, TQ_SLOT(slotHHtoPCRequested()),
 		actionCollection(), "file_HHtoPC");
 	a->setToolTip(i18n("Next HotSync will be backup."));
 	a->setWhatsThis(i18n("Tell the daemon that the next HotSync "
@@ -564,7 +564,7 @@ void KPilotInstaller::initMenu()
 	syncPopup->insert(a);
 
 	a = new TDEAction(i18n("Copy PC to Handheld"), TQString(), 0,
-		TQT_TQOBJECT(this), TQT_SLOT(slotPCtoHHRequested()),
+		this, TQ_SLOT(slotPCtoHHRequested()),
 		actionCollection(), "file_PCtoHH");
 	a->setToolTip(i18n("Next HotSync will copy PC to Handheld."));
 	a->setWhatsThis(i18n("Tell the daemon that the next HotSync "
@@ -575,7 +575,7 @@ void KPilotInstaller::initMenu()
 
 #if 0
 	a = new TDEAction(i18n("&List Only"),CSL1("listsync"),0,
-		this,TQT_SLOT(slotTestSyncRequested()),
+		this,TQ_SLOT(slotTestSyncRequested()),
 		actionCollection(), "file_list");
 	a->setToolTip(i18n("Next HotSync will list databases."));
 	a->setWhatsThis(i18n("Tell the daemon that the next HotSync "
@@ -586,14 +586,14 @@ void KPilotInstaller::initMenu()
 
 
 	a = new TDEAction(i18n("Rese&t Link"),CSL1("reload"), 0,
-		TQT_TQOBJECT(this), TQT_SLOT(slotResetLink()),
+		this, TQ_SLOT(slotResetLink()),
 		actionCollection(),"file_reload");
 	a->setToolTip(i18n("Reset the device connection."));
 	a->setWhatsThis(i18n("Try to reset the daemon and its connection "
 		"to the Handheld."));
 
 
-	a = KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(quit()), actionCollection());
+	a = KStdAction::quit(this, TQ_SLOT(quit()), actionCollection());
 	a->setWhatsThis(i18n("Quit KPilot, (and stop the daemon "
 		"if configured that way)."));
 
@@ -603,15 +603,15 @@ void KPilotInstaller::initMenu()
 	createStandardStatusBarAction();
 	setStandardToolBarMenuEnabled(true);
 
-	(void) KStdAction::keyBindings(TQT_TQOBJECT(this), TQT_SLOT(optionsConfigureKeys()),
+	(void) KStdAction::keyBindings(this, TQ_SLOT(optionsConfigureKeys()),
 		actionCollection());
-	(void) KStdAction::configureToolbars(TQT_TQOBJECT(this), TQT_SLOT(optionsConfigureToolbars()),
+	(void) KStdAction::configureToolbars(this, TQ_SLOT(optionsConfigureToolbars()),
 		actionCollection());
-	(void) KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(configure()),
+	(void) KStdAction::preferences(this, TQ_SLOT(configure()),
 		actionCollection());
 
 	a = new TDEAction(i18n("Configuration &Wizard..."), CSL1("wizard"), 0,
-		TQT_TQOBJECT(this), TQT_SLOT(configureWizard()),
+		this, TQ_SLOT(configureWizard()),
 		actionCollection(), "options_configure_wizard");
 	a->setWhatsThis(i18n("Configure KPilot using the configuration wizard."));
 
@@ -685,13 +685,13 @@ void KPilotInstaller::addComponentPage(PilotComponent * p,
 
 	TDEToggleAction *pt =
 		new TDEToggleAction(name, /* "kpilot" -- component icon, */ 0,
-		TQT_TQOBJECT(p), TQT_SLOT(slotShowComponent()),
+		p, TQ_SLOT(slotShowComponent()),
 		actionCollection(), actionname);
 
 	pt->setExclusiveGroup(CSL1("view_menu"));
 
-	connect(TQT_TQOBJECT(p), TQT_SIGNAL(showComponent(PilotComponent *)),
-		TQT_TQOBJECT(this), TQT_SLOT(slotSelectComponent(PilotComponent *)));
+	connect(p, TQ_SIGNAL(showComponent(PilotComponent *)),
+		this, TQ_SLOT(slotSelectComponent(PilotComponent *)));
 }
 
 /* slot */ void KPilotInstaller::initializeComponents()
@@ -719,7 +719,7 @@ void KPilotInstaller::optionsConfigureToolbars()
 	// This was added in KDE 3.1
 	saveMainWindowSettings( TDEGlobal::config(), autoSaveGroup() );
 	KEditToolbar dlg(actionCollection());
-	connect(&dlg, TQT_SIGNAL(newToolbarConfig()), TQT_TQOBJECT(this), TQT_SLOT(slotNewToolbarConfig()));
+	connect(&dlg, TQ_SIGNAL(newToolbarConfig()), this, TQ_SLOT(slotNewToolbarConfig()));
 	dlg.exec();
 }
 
@@ -1124,7 +1124,7 @@ int main(int argc, char **argv)
 		return 1;
 	}
 
-	TQTimer::singleShot(0,tp,TQT_SLOT(startDaemonIfNeeded()));
+	TQTimer::singleShot(0,tp,TQ_SLOT(startDaemonIfNeeded()));
 
 	TDEGlobal::dirs()->addResourceType("pilotdbs",
 		CSL1("share/apps/kpilot/DBBackup"));
