@@ -111,7 +111,7 @@ ProbeDialog::ProbeDialog(TQWidget *parent, const char *n) :
 
 
 	fResultsGroup = new TQGroupBox( i18n( "Detected Values" ), mainWidget, "fResultsGroup" );
-	fResultsGroup->setEnabled( FALSE );
+	fResultsGroup->setEnabled( false );
 	fResultsGroup->setColumnLayout(0, TQt::Vertical );
 	fResultsGroupLayout = new TQGridLayout( fResultsGroup->layout() );
 	fResultsGroupLayout->setAlignment( TQt::AlignTop );
