@@ -63,7 +63,7 @@ class TQStringList;
 
 class ListCategorizer : public TDEListView
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
