@@ -119,14 +119,14 @@ PilotDaemonTray::PilotDaemonTray(PilotDaemon * p) :
 
 	switch (e->button())
 	{
-		case Qt::RightButton:
+		case TQt::RightButton:
 			{
 				TDEPopupMenu *menu = contextMenu();
 				contextMenuAboutToShow(menu);
 				menu->popup(e->globalPos());
 			}
 			break;
-		case Qt::LeftButton:
+		case TQt::LeftButton:
 			if (daemon) daemon->slotRunKPilot();
 			break;
 		default:
@@ -150,14 +150,14 @@ void PilotDaemonTray::setupWidget()
 	icons[NotListening] = loadIcon( CSL1("nosync") );
 
 	slotShowNotListening();
-	TQTimer::singleShot(2000,this,TQT_SLOT(slotShowNormal()));
+	TQTimer::singleShot(2000,this,TQ_SLOT(slotShowNormal()));
 
 	TDEPopupMenu *menu = contextMenu();
 
 	menuKPilotItem = menu->insertItem(i18n("Start &KPilot"), daemon,
-		TQT_SLOT(slotRunKPilot()));
+		TQ_SLOT(slotRunKPilot()));
 	menuConfigureConduitsItem = menu->insertItem(i18n("&Configure KPilot..."),
-		daemon, TQT_SLOT(slotRunConfig()));
+		daemon, TQ_SLOT(slotRunConfig()));
 	menu->insertSeparator();
 
 	fSyncTypeMenu = new TDEPopupMenu(menu,"sync_type_menu");
@@ -181,7 +181,7 @@ void PilotDaemonTray::setupWidget()
 	fSyncTypeMenu->setCheckable(true);
 	fSyncTypeMenu->setItemChecked(0,true);
 #undef MI
-	connect(fSyncTypeMenu,TQT_SIGNAL(activated(int)),daemon,TQT_SLOT(requestSync(int)));
+	connect(fSyncTypeMenu,TQ_SIGNAL(activated(int)),daemon,TQ_SLOT(requestSync(int)));
 	menu->insertItem(i18n("Next &Sync"),fSyncTypeMenu);
 
 	KHelpMenu *help = new KHelpMenu(menu,aboutData);
@@ -261,8 +261,8 @@ void PilotDaemonTray::startHotSync()
 	}
 	if (fBlinkTimer)
 	{
-		connect(fBlinkTimer,TQT_SIGNAL(timeout()),
-			this,TQT_SLOT(slotBusyTimer()));
+		connect(fBlinkTimer,TQ_SIGNAL(timeout()),
+			this,TQ_SLOT(slotBusyTimer()));
 		fBlinkTimer->start(750,false);
 	}
 }
@@ -305,8 +305,8 @@ PilotDaemon::PilotDaemon() :
 
 	fInstaller = new FileInstaller;
 	fLogFile = new LogFile;
-	connect(fInstaller, TQT_SIGNAL(filesChanged()),
-		this, TQT_SLOT(slotFilesChanged()));
+	connect(fInstaller, TQ_SIGNAL(filesChanged()),
+		this, TQ_SLOT(slotFilesChanged()));
 
 	fNextSyncType.setMode( KPilotSettings::syncType() );
 
@@ -594,16 +594,16 @@ bool PilotDaemon::setupPilotLink()
 		return false;
 	}
 
-	TQObject::connect(fPilotLink, TQT_SIGNAL(deviceReady(KPilotLink*)),
-		this, TQT_SLOT(startHotSync(KPilotLink*)));
+	TQObject::connect(fPilotLink, TQ_SIGNAL(deviceReady(KPilotLink*)),
+		this, TQ_SLOT(startHotSync(KPilotLink*)));
 	// connect the signals emitted by the pilotDeviceLink
-	TQObject::connect(fPilotLink, TQT_SIGNAL(logError(const TQString &)),
-		this, TQT_SLOT(logError(const TQString &)));
-	TQObject::connect(fPilotLink, TQT_SIGNAL(logMessage(const TQString &)),
-		this, TQT_SLOT(logMessage(const TQString &)));
+	TQObject::connect(fPilotLink, TQ_SIGNAL(logError(const TQString &)),
+		this, TQ_SLOT(logError(const TQString &)));
+	TQObject::connect(fPilotLink, TQ_SIGNAL(logMessage(const TQString &)),
+		this, TQ_SLOT(logMessage(const TQString &)));
 	TQObject::connect(fPilotLink,
-		TQT_SIGNAL(logProgress(const TQString &,int)),
-		this, TQT_SLOT(logProgress(const TQString &,int)));
+		TQ_SIGNAL(logProgress(const TQString &,int)),
+		this, TQ_SLOT(logProgress(const TQString &,int)));
 
 
 	return true;
@@ -1107,18 +1107,18 @@ bool PilotDaemon::shouldBackup()
 launch:
 	fSyncStack->queueCleanup();
 
-	TQObject::connect(fSyncStack, TQT_SIGNAL(logError(const TQString &)),
-		this, TQT_SLOT(logError(const TQString &)));
-	TQObject::connect(fSyncStack, TQT_SIGNAL(logMessage(const TQString &)),
-		this, TQT_SLOT(logMessage(const TQString &)));
+	TQObject::connect(fSyncStack, TQ_SIGNAL(logError(const TQString &)),
+		this, TQ_SLOT(logError(const TQString &)));
+	TQObject::connect(fSyncStack, TQ_SIGNAL(logMessage(const TQString &)),
+		this, TQ_SLOT(logMessage(const TQString &)));
 	TQObject::connect(fSyncStack,
-		TQT_SIGNAL(logProgress(const TQString &,int)),
-		this, TQT_SLOT(logProgress(const TQString &,int)));
+		TQ_SIGNAL(logProgress(const TQString &,int)),
+		this, TQ_SLOT(logProgress(const TQString &,int)));
 
-	TQObject::connect(fSyncStack, TQT_SIGNAL(syncDone(SyncAction *)),
-		this, TQT_SLOT(endHotSync()));
+	TQObject::connect(fSyncStack, TQ_SIGNAL(syncDone(SyncAction *)),
+		this, TQ_SLOT(endHotSync()));
 
-	TQTimer::singleShot(0,fSyncStack,TQT_SLOT(execConduit()));
+	TQTimer::singleShot(0,fSyncStack,TQ_SLOT(execConduit()));
 
 	updateTrayStatus();
 }
@@ -1183,7 +1183,7 @@ launch:
 	}
 	else
 	{
-		TQTimer::singleShot(10000,fPilotLink,TQT_SLOT(reset()));
+		TQTimer::singleShot(10000,fPilotLink,TQ_SLOT(reset()));
 	}
 
 	fPostSyncAction = None;
