@@ -223,11 +223,11 @@ void TodoWidget::setupWidget()
 
 	fListBox = new TodoListView(this);
 	fListBox->addColumn( i18n( "To-do Item" ) );
-	fListBox->setAllColumnsShowFocus( TRUE );
+	fListBox->setAllColumnsShowFocus( true );
 	fListBox->setResizeMode( TDEListView::LastColumn );
-	fListBox->setFullWidth( TRUE );
-	fListBox->setItemsMovable( FALSE );
-	fListBox->setItemsRenameable (TRUE);
+	fListBox->setFullWidth( true );
+	fListBox->setItemsMovable( false );
+	fListBox->setItemsRenameable (true);
 	grid->addMultiCellWidget(fListBox, 1, 1, 0, 1);
 	connect(fListBox, TQ_SIGNAL(selectionChanged(TQListViewItem*)),
 		this, TQ_SLOT(slotShowTodo(TQListViewItem*)));
