@@ -42,7 +42,7 @@
 * It is added automatically to a ActionQueue by queueInit() in order
 * to inform the user of the sync.
 */
-class KDE_EXPORT WelcomeAction : public SyncAction
+class TDE_EXPORT WelcomeAction : public SyncAction
 {
 public:
 	/** Constructor. */
@@ -58,7 +58,7 @@ protected:
 * in cases when the hotsync starts while KPilot is busy configuring
 * something and can't be interrupted.
 */
-class KDE_EXPORT SorryAction : public SyncAction
+class TDE_EXPORT SorryAction : public SyncAction
 {
 public:
 	/**
@@ -84,7 +84,7 @@ protected:
 * device that the HotSync is over, it should be the last
 * action executed.
 */
-class KDE_EXPORT CleanupAction : public SyncAction
+class TDE_EXPORT CleanupAction : public SyncAction
 {
 public:
 	/** Constructor. */
@@ -100,7 +100,7 @@ protected:
 * and not do anything spectacular. It lists all the databases
 * on the handheld in the sync log.
 */
-class KDE_EXPORT TestLink : public SyncAction
+class TDE_EXPORT TestLink : public SyncAction
 {
 public:
 	/** Constructor. */
